@@ -31,7 +31,8 @@
 #' @importFrom stats na.omit
 #'
 #' @examples
-#' \dontrun{
+#'
+#' \donttest{
 #' set.seed(123)
 #' ggstatsplot:::t1way_ci(
 #'   data = dplyr::filter(ggplot2::msleep, vore != "insecti"),
@@ -180,7 +181,8 @@ t1way_ci <- function(data,
 #' @importFrom stats na.omit
 #'
 #' @examples
-#' \dontrun{
+#'
+#' \donttest{
 #' ggstatsplot:::yuend_ci(
 #'   data = dplyr::filter(
 #'     .data = ggstatsplot::iris_long,
@@ -323,182 +325,6 @@ yuend_ci <- function(data,
   return(results_df)
 }
 
-
-#' @title A correlation test with confidence interval for effect size.
-#' @name cor_test_ci
-#' @description Custom function to get confidence intervals for effect size
-#'   measure for parametric or non-parametric correlation coefficient.
-#'
-#' @param x A vector containing the explanatory variable.
-#' @param y The response - a vector of length the number of rows of `x`.
-#' @inheritDotParams boot::boot
-#' @inheritParams stats::cor.test
-#' @inheritParams t1way_ci
-#'
-#' @importFrom tibble as_tibble
-#' @importFrom dplyr select
-#' @importFrom rlang !! enquo
-#' @importFrom WRS2 t1way
-#' @importFrom boot boot boot.ci
-#' @importFrom stats na.omit
-#'
-#' @examples
-#' \dontrun{
-#' ggstatsplot:::cor_test_ci(
-#'   data = ggplot2::msleep,
-#'   x = brainwt,
-#'   y = sleep_total,
-#'   nboot = 25,
-#'   conf.level = 0.99,
-#'   conf.type = "perc",
-#'   method = "spearman",
-#'   continuity = TRUE,
-#'   alternative = "greater"
-#' )
-#' }
-#'
-#' @keywords internal
-
-# function body
-cor_test_ci <- function(data,
-                        x,
-                        y,
-                        method = "spearman",
-                        exact = FALSE,
-                        continuity = TRUE,
-                        alternative = "two.sided",
-                        nboot = 100,
-                        conf.level = 0.95,
-                        conf.type = "norm",
-                        ...) {
-  # creating a dataframe from entered data
-  data <- dplyr::select(
-    .data = data,
-    x = !!rlang::enquo(x),
-    y = !!rlang::enquo(y)
-  ) %>%
-    dplyr::filter(.data = ., !is.na(x), !is.na(y)) %>%
-    tibble::as_tibble(x = .)
-
-  # running correlation and creating a tidy dataframe
-  tidy_df <- broomExtra::tidy(
-    x = stats::cor.test(
-      formula = stats::as.formula(~ x + y),
-      data = data,
-      method = method,
-      exact = exact,
-      continuity = continuity,
-      alternative = alternative
-    )
-  )
-
-  # function to obtain 95% CI for xi
-  corci <- function(formula,
-                      x,
-                      y,
-                      method = method,
-                      exact = exact,
-                      continuity = continuity,
-                      alternative = alternative,
-                      indices) {
-    # allows boot to select sample
-    d <- data[indices, ]
-    # allows boot to select sample
-    boot_df <-
-      broomExtra::tidy(
-        stats::cor.test(
-          formula = stats::as.formula(~ x + y),
-          data = d,
-          method = method,
-          exact = exact,
-          continuity = continuity,
-          alternative = alternative,
-          na.action = na.omit
-        )
-      )
-
-    # return the value of interest: effect size
-    return(boot_df$estimate)
-  }
-
-  # save the bootstrapped results to an object
-  bootobj <- boot::boot(
-    data = data,
-    statistic = corci,
-    R = nboot,
-    x = x,
-    y = y,
-    method = method,
-    exact = exact,
-    continuity = continuity,
-    alternative = alternative,
-    parallel = "multicore",
-    ...
-  )
-
-  # get 95% CI from the bootstrapped object
-  bootci <- boot::boot.ci(
-    boot.out = bootobj,
-    conf = conf.level,
-    type = conf.type
-  )
-
-  # extracting ci part
-  if (conf.type == "norm") {
-    ci <- bootci$normal
-  } else if (conf.type == "basic") {
-    ci <- bootci$basic
-  } else if (conf.type == "perc") {
-    ci <- bootci$perc
-  } else if (conf.type == "bca") {
-    ci <- bootci$bca
-  }
-
-  # preparing a dataframe out of the results
-  results_df <-
-    tibble::as_tibble(
-      x = cbind.data.frame(
-        "r" = tidy_df$estimate,
-        ci,
-        "statistic" = tidy_df$statistic,
-        "p.value" = tidy_df$p.value,
-        "nboot" = bootci$R,
-        "method" = tidy_df$method,
-        "alternative" = as.character(alternative)
-      )
-    )
-
-  # selecting the columns corresponding to the confidence intervals
-  if (conf.type == "norm") {
-    results_df %<>%
-      dplyr::select(
-        .data = .,
-        r,
-        conf.low = V2,
-        conf.high = V3,
-        p.value,
-        conf,
-        nboot,
-        dplyr::everything()
-      )
-  } else {
-    results_df %<>%
-      dplyr::select(
-        .data = .,
-        r,
-        conf.low = V4,
-        conf.high = V5,
-        p.value,
-        conf,
-        nboot,
-        dplyr::everything()
-      )
-  }
-
-  # return the final dataframe
-  return(results_df)
-}
-
 #' @title Robust correlation coefficient and its confidence interval
 #' @name robcor_ci
 #' @description Custom function to get confidence intervals for percentage bend
@@ -522,7 +348,8 @@ cor_test_ci <- function(data,
 #' @importFrom stats na.omit
 #'
 #' @examples
-#' \dontrun{
+#'
+#' \donttest{
 #' ggstatsplot:::robcor_ci(
 #'   data = mtcars,
 #'   x = "hp",
@@ -662,7 +489,8 @@ robcor_ci <- function(data,
 #' @importFrom stats na.omit
 #'
 #' @examples
-#' \dontrun{
+#'
+#' \donttest{
 #' ggstatsplot:::kw_eta_h_ci(
 #'   data = ggplot2::msleep,
 #'   x = vore,
@@ -788,7 +616,7 @@ kw_eta_h_ci <- function(data,
   # preparing a dataframe out of the results
   results_df <-
     tibble::as_tibble(x = cbind.data.frame(
-      "eta_sq_H" = eta_sq_H,
+      "estimate" = eta_sq_H,
       ci,
       "nboot" = bootci$R
     ))
@@ -798,7 +626,7 @@ kw_eta_h_ci <- function(data,
     results_df %<>%
       dplyr::select(
         .data = .,
-        eta_sq_H,
+        estimate,
         conf.low = V2,
         conf.high = V3,
         conf,
@@ -808,7 +636,7 @@ kw_eta_h_ci <- function(data,
     results_df %<>%
       dplyr::select(
         .data = .,
-        eta_sq_H,
+        estimate,
         conf.low = V4,
         conf.high = V5,
         conf,
