@@ -5,7 +5,6 @@ context(desc = "ggbarstats")
 testthat::test_that(
   desc = "checking labels with counts",
   code = {
-    testthat::skip_on_cran()
 
     # condition variable is not options for ggbarstats
     testthat::expect_error(ggstatsplot::ggbarstats(
@@ -25,6 +24,7 @@ testthat::test_that(
       xlab = "Passenger sex",
       ylab = "proportion",
       label.separator = "\n",
+      bf.message = FALSE,
       messages = TRUE
     )
 
@@ -64,6 +64,7 @@ testthat::test_that(
 
     # checking plot labels
     testthat::expect_identical(pb$plot$labels$subtitle, p_subtitle)
+    testthat::expect_identical(pb$plot$labels$caption, NULL)
     testthat::expect_identical(pb$plot$labels$x, "Passenger sex")
     testthat::expect_identical(pb$plot$labels$y, "proportion")
 
@@ -144,7 +145,7 @@ testthat::test_that(
       data = mtcars,
       main = vs,
       condition = cyl,
-      data.label = "counts",
+      bar.label = "counts",
       bf.message = FALSE,
       nboot = 10,
       x.axis.orientation = "vertical",
@@ -195,3 +196,84 @@ testthat::test_that(
     testthat::expect_identical(pb1$plot$theme$legend.position, "right")
   }
 )
+
+# subtitle return --------------------------------------------------
+
+testthat::test_that(
+  desc = "subtitle return",
+  code = {
+    testthat::skip_on_cran()
+
+    # subtitle return
+    set.seed(123)
+    p_sub <- ggstatsplot::ggbarstats(
+      data = dplyr::sample_frac(tbl = forcats::gss_cat, size = 0.1),
+      main = race,
+      condition = marital,
+      return = "subtitle",
+      k = 4,
+      messages = FALSE
+    )
+
+    # caption return
+    set.seed(123)
+    p_cap <- ggstatsplot::ggbarstats(
+      data = dplyr::sample_frac(tbl = forcats::gss_cat, size = 0.1),
+      main = race,
+      condition = marital,
+      return = "caption",
+      k = 4,
+      messages = FALSE
+    )
+
+    # tests
+    testthat::expect_identical(p_sub, ggplot2::expr(
+      paste(
+        NULL,
+        italic(chi)^2,
+        "(",
+        "8",
+        ") = ",
+        "109.2007",
+        ", ",
+        italic("p"),
+        " = ",
+        "< 0.001",
+        ", ",
+        italic("V")["Cramer"],
+        " = ",
+        "0.1594",
+        ", CI"["95%"],
+        " [",
+        "0.0916",
+        ", ",
+        "0.1278",
+        "]",
+        ", ",
+        italic("n"),
+        " = ",
+        2148L
+      )
+    ))
+
+    testthat::expect_identical(
+      p_cap,
+      ggplot2::expr(atop(
+        displaystyle(NULL),
+        expr = paste(
+          "In favor of null: ",
+          "log"["e"],
+          "(BF"["01"],
+          ") = ",
+          "-36.8983",
+          ", sampling = ",
+          "independent multinomial",
+          ", ",
+          italic("a"),
+          " = ",
+          "1.0000"
+        )
+      ))
+    )
+  }
+)
